==> sagua_0.1.2-1.tar.gz: sagua-0.1.2/src/mainmanager.cc <==
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file mainmanager.cc
/// @brief Class for main program control mediator source file.

#include "../include/mainmanager.h"
#include "../include/aboutdlg.h"

/// @brief Constructor of MainManager.
/// @param arguments Command line arguments.
/// @param socket UnixSocket object to accept a connection.
MainManager::MainManager(const std::vector<std::string>& arguments, UnixSocket& socket)
    : audioFormatLittleEndian_(AO_FMT_LITTLE),
    audioFormatBigEndian_(AO_FMT_BIG),
    audioFormatNativeEndian_(AO_FMT_NATIVE),
    socket_(socket),
    trayIcon_(*this),
    mixer_(Mixer::Create(*this)),
    mainWnd_(*this, arguments)
{
    audio_ = Audio::Create(*this);

    trayIconFirstBtnCallbacks_["prev"] = &MainManager::PlayCtrlPrev;
    trayIconFirstBtnCallbacks_["play"] = &MainManager::PlayCtrlPlay;
    trayIconFirstBtnCallbacks_["pause"] = &MainManager::AudioPauseToggle;
    trayIconFirstBtnCallbacks_["stop"] = &MainManager::PlayCtrlStop;
    trayIconFirstBtnCallbacks_["next"] = &MainManager::PlayCtrlNext;
    trayIconFirstBtnCallbacks_["fileinfo"] = &MainManager::FileInfo;

    mainWnd_.show();

    if(!preference_.SuccessLoadConfig())
	mainWnd_.OnMenuPreference();
}

MainManager::~MainManager()
{}

/// @brief Hide MainWnd.
void MainManager::MainWndIconifyEvent()
{
    mainWnd_.hide();
    mainWnd_.SetSkipTimeUpdate(true);
    trayIcon_.ToggleMainWndOpenMenuSensitivity(true);
}

/// @brief Show MainWnd.
void MainManager::MainWndDeiconify()
{
    trayIcon_.ToggleMainWndOpenMenuSensitivity(false);
    mainWnd_.SetSkipTimeUpdate(false);
    mainWnd_.TimeUpdate();
    mainWnd_.show();
}

/// @brief Show about dialog.
void MainManager::About()
{
    AboutDlg aboutDlg;

    aboutDlg.run();
}

/// @brief Hide MainWnd and exit loop.
void MainManager::Quit()
{
    mainWnd_.SaveState();
    mainWnd_.hide();

    Gtk::Main::quit();
}

==> sagua_0.2.0-1.tar.gz: sagua-0.2.0/src/mainmanager.cc <==
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file mainmanager.cc
/// @brief Class for main program control mediator source file.

#include "../include/mainmanager.h"
#include "../include/aboutdlg.h"

/// @brief Constructor of MainManager.
/// @param arguments Command line arguments.
/// @param socketHandler UnixSocketHandler object to accept a connection.
MainManager::MainManager(const std::vector<std::string>& arguments, UnixSocketHandler& socketHandler)
    : audioFormatLittleEndian_(AO_FMT_LITTLE),
    audioFormatBigEndian_(AO_FMT_BIG),
    audioFormatNativeEndian_(AO_FMT_NATIVE),
    socketHandler_(socketHandler),
    trayIcon_(*this),
    mixer_(Mixer::Create(*this)),
    mainWnd_(*this, arguments),
    mainWndIconified_(false)
{
    audio_ = Audio::Create(*this);

    trayIconFirstBtnCallbacks_["openwin"] = &MainManager::MainWndOpen;
    trayIconFirstBtnCallbacks_["prev"] = &MainManager::PlayCtrlPrev;
    trayIconFirstBtnCallbacks_["play"] = &MainManager::PlayCtrlPlay;
    trayIconFirstBtnCallbacks_["pause"] = &MainManager::AudioPauseToggle;
    trayIconFirstBtnCallbacks_["stop"] = &MainManager::PlayCtrlStop;
    trayIconFirstBtnCallbacks_["next"] = &MainManager::PlayCtrlNext;
    trayIconFirstBtnCallbacks_["fileinfo"] = &MainManager::FileInfo;

    mainWnd_.show();

    if(preference_.SuccessLoadConfig())
	mainWnd_.PlayQueue();
    else	
	mainWnd_.OnMenuPreference();
	
}

MainManager::~MainManager()
{}

/// @brief Hide MainWnd.
void MainManager::MainWndIconify()
{
    mainWndIconified_ = true;
    
    mainWnd_.SetSkipTimeUpdate(true);

    if(HideMainWndOnIconify())
	mainWnd_.hide();
    else
	mainWnd_.iconify();
}

/// @brief Show MainWnd.
void MainManager::MainWndOpen()
{
    if(mainWndIconified_) {
	mainWnd_.SetSkipTimeUpdate(false);
	mainWnd_.TimeUpdate();
	mainWndIconified_ = false;

	if(HideMainWndOnIconify())
	    mainWnd_.show();
	else
	    mainWnd_.deiconify();
    }

    mainWnd_.raise();	
}

/// @brief Show about dialog.
void MainManager::About()
{
    AboutDlg aboutDlg;

    aboutDlg.run();
}

/// @brief Hide MainWnd and exit loop.
void MainManager::Quit()
{
    mainWnd_.SaveState();
    mainWnd_.hide();

    Gtk::Main::quit();
}
